@@ -26,6 +26,7 @@
 #include <Qt3DRender/QCullFace>
 
 #include "qgsmultipolygon.h"
+#include "qgspolygon.h"
 #include "qgsmeshlayer.h"
 #include "qgstriangularmesh.h"
 #include "qgsexpressioncontextutils.h"
@@ -123,7 +124,7 @@ Qt3DRender::QGeometryRenderer *QgsMesh3DSymbolEntityNode::renderer( const Qgs3DM
       std::unique_ptr< QgsPolygon > polygon = QgsMeshUtils::toPolygon( triangle, vertices );
       Qgs3DUtils::clampAltitudes( polygon.get(),
                                   symbol.altitudeClamping(),
-                                  Qgs3DTypes::AltitudeBinding::AltBindVertex,
+                                  Qgis::AltitudeBinding::Vertex,
                                   height,
                                   map );
       polygons.append( polygon.release() );
