@@ -18,6 +18,7 @@
 #include "qgsmessagelog.h"
 #include "qgslogger.h"
 #include "qgsgeonoderequest.h"
+#include "qgsvariantutils.h"
 
 #include <QEventLoop>
 #include <QNetworkCacheMetaData>
@@ -54,18 +55,22 @@ void QgsGeoNodeRequest::abort()
 void QgsGeoNodeRequest::fetchLayers()
 {
   request( QStringLiteral( "/api/layers/" ) );
-  QObject *obj = new QObject( this );
 
+  QObject *obj = new QObject( this );
   connect( this, &QgsGeoNodeRequest::requestFinished, obj, [obj, this ]
   {
-    QList<QgsGeoNodeRequest::ServiceLayerDetail> layers;
-    if ( mError.isEmpty() )
+    if ( !mParsingLayers )
     {
-      layers = parseLayers( this->lastResponse() );
+      mParsingLayers = true;
+      QList<QgsGeoNodeRequest::ServiceLayerDetail> layers;
+      if ( mError.isEmpty() )
+      {
+        layers = parseLayers( lastResponse() );
+      }
+      emit layersFetched( layers );
+      mParsingLayers = false;
+      obj->deleteLater();
     }
-    emit layersFetched( layers );
-
-    obj->deleteLater();
   } );
 }
 
@@ -74,11 +79,11 @@ QList<QgsGeoNodeRequest::ServiceLayerDetail> QgsGeoNodeRequest::fetchLayersBlock
   QList<QgsGeoNodeRequest::ServiceLayerDetail> layers;
 
   QEventLoop loop;
-  connect( this, &QgsGeoNodeRequest::requestFinished, &loop, &QEventLoop::quit );
   QObject *obj = new QObject( this );
   connect( this, &QgsGeoNodeRequest::layersFetched, obj, [&]( const QList<QgsGeoNodeRequest::ServiceLayerDetail> &fetched )
   {
     layers = fetched;
+    loop.exit();
   } );
   fetchLayers();
   loop.exec( QEventLoop::ExcludeUserInputEvents );
@@ -164,14 +169,14 @@ void QgsGeoNodeRequest::setProtocol( const QString &protocol )
 
 void QgsGeoNodeRequest::replyFinished()
 {
-  QgsDebugMsg( QStringLiteral( "Reply finished" ) );
+  QgsDebugMsgLevel( QStringLiteral( "Reply finished" ), 2 );
   if ( !mIsAborted && mGeoNodeReply )
   {
     if ( mGeoNodeReply->error() == QNetworkReply::NoError )
     {
-      QgsDebugMsg( QStringLiteral( "reply OK" ) );
+      QgsDebugMsgLevel( QStringLiteral( "reply OK" ), 2 );
       QVariant redirect = mGeoNodeReply->attribute( QNetworkRequest::RedirectionTargetAttribute );
-      if ( !redirect.isNull() )
+      if ( !QgsVariantUtils::isNull( redirect ) )
       {
 
         emit statusChanged( QStringLiteral( "GeoNode request redirected." ) );
@@ -218,7 +223,7 @@ void QgsGeoNodeRequest::replyFinished()
           }
           cmd.setRawHeaders( hl );
 
-          QgsDebugMsg( QStringLiteral( "expirationDate:%1" ).arg( cmd.expirationDate().toString() ) );
+          QgsDebugMsgLevel( QStringLiteral( "expirationDate:%1" ).arg( cmd.expirationDate().toString() ), 2 );
           if ( cmd.expirationDate().isNull() )
           {
             QgsSettings settings;
@@ -270,9 +275,9 @@ QList<QgsGeoNodeRequest::ServiceLayerDetail> QgsGeoNodeRequest::parseLayers( con
   const QVariantMap jsonVariantMap = jsonObject.toVariantMap();
   const QVariantList layerList = jsonVariantMap.value( QStringLiteral( "objects" ) ).toList();
 
-  QString wmsURLFormat, wfsURLFormat, xyzURLFormat;
+  QString wmsURLFormat, wfsURLFormat, wcsURLFormat, xyzURLFormat;
 
-  for ( const QVariant &layer : qgis::as_const( layerList ) )
+  for ( const QVariant &layer : std::as_const( layerList ) )
   {
     QgsGeoNodeRequest::ServiceLayerDetail layerStruct;
     const QVariantMap layerMap = layer.toMap();
@@ -283,7 +288,7 @@ QList<QgsGeoNodeRequest::ServiceLayerDetail> QgsGeoNodeRequest::parseLayers( con
       const QStringList splitUrl = layerMap.value( QStringLiteral( "detail_url" ) ).toString().split( '/' );
       layerStruct.typeName = !splitUrl.isEmpty() ? splitUrl.last() : QString();
     }
-    layerStruct.uuid = layerMap.value( QStringLiteral( "uuid" ) ).toString();
+    layerStruct.uuid = QUuid( layerMap.value( QStringLiteral( "uuid" ) ).toString() );
     layerStruct.id = layerMap.value( QStringLiteral( "id" ) ).toString();
     layerStruct.name = layerMap.value( QStringLiteral( "name" ) ).toString();
     layerStruct.typeName = layerMap.value( QStringLiteral( "typename" ) ).toString();
@@ -291,9 +296,9 @@ QList<QgsGeoNodeRequest::ServiceLayerDetail> QgsGeoNodeRequest::parseLayers( con
 
     if ( ! layerMap.contains( QStringLiteral( "links" ) ) )
     {
-      if ( wmsURLFormat.isEmpty() && wfsURLFormat.isEmpty() && xyzURLFormat.isEmpty() )
+      if ( wmsURLFormat.isEmpty() && wfsURLFormat.isEmpty() && wcsURLFormat.isEmpty() && xyzURLFormat.isEmpty() )
       {
-        bool success = requestBlocking( QStringLiteral( "/api/layers/" ) + layerStruct.id );
+        bool success = requestBlocking( QStringLiteral( "/api/layers/%1/" ).arg( layerStruct.id ) );
         if ( success )
         {
           const QJsonDocument resourceUriDocument = QJsonDocument::fromJson( this->lastResponse() );
@@ -303,17 +308,18 @@ QList<QgsGeoNodeRequest::ServiceLayerDetail> QgsGeoNodeRequest::parseLayers( con
           QgsGeoNodeRequest::ServiceLayerDetail tempLayerStruct;
           tempLayerStruct = parseOwsUrl( tempLayerStruct, resourceUriLinks );
 
-          if ( tempLayerStruct.wmsURL.isEmpty() && tempLayerStruct.wfsURL.isEmpty() && tempLayerStruct.xyzURL.isEmpty() )
+          if ( tempLayerStruct.wmsURL.isEmpty() && tempLayerStruct.wfsURL.isEmpty() && tempLayerStruct.wcsURL.isEmpty() && tempLayerStruct.xyzURL.isEmpty() )
             continue;
 
           // Avoid iterating all the layers to get the service url. Instead, generate a string format once we found one service url
-          // for every service (wms, wfs, xyz). And then use the string format for the other layers since they are identical.
+          // for every service (wms, wfs, wcs, xyz). And then use the string format for the other layers since they are identical.
           switch ( tempLayerStruct.server )
           {
             case QgsGeoNodeRequest::BackendServer::QgisServer:
             {
               wmsURLFormat = ! tempLayerStruct.wmsURL.isEmpty() ? tempLayerStruct.wmsURL.replace( layerStruct.name, QStringLiteral( "%1" ) ) : QString();
               wfsURLFormat = ! tempLayerStruct.wfsURL.isEmpty() ? tempLayerStruct.wfsURL.replace( layerStruct.name, QStringLiteral( "%1" ) ) : QString();
+              wcsURLFormat = ! tempLayerStruct.wcsURL.isEmpty() ? tempLayerStruct.wcsURL.replace( layerStruct.name, QStringLiteral( "%1" ) ) : QString();
               xyzURLFormat = ! tempLayerStruct.xyzURL.isEmpty() ? tempLayerStruct.xyzURL.replace( layerStruct.name, QStringLiteral( "%1" ) ) : QString();
               break;
             }
@@ -321,6 +327,7 @@ QList<QgsGeoNodeRequest::ServiceLayerDetail> QgsGeoNodeRequest::parseLayers( con
             {
               wmsURLFormat = ! tempLayerStruct.wmsURL.isEmpty() ? tempLayerStruct.wmsURL : QString();
               wfsURLFormat = ! tempLayerStruct.wfsURL.isEmpty() ? tempLayerStruct.wfsURL : QString();
+              wcsURLFormat = ! tempLayerStruct.wcsURL.isEmpty() ? tempLayerStruct.wcsURL : QString();
               xyzURLFormat = ! tempLayerStruct.xyzURL.isEmpty() ? tempLayerStruct.xyzURL.replace( layerStruct.name, QStringLiteral( "%1" ) ) : QString();
               break;
             }
@@ -336,6 +343,7 @@ QList<QgsGeoNodeRequest::ServiceLayerDetail> QgsGeoNodeRequest::parseLayers( con
         // Replace string argument with the layer id.
         layerStruct.wmsURL = wmsURLFormat.contains( "%1" ) ? wmsURLFormat.arg( layerStruct.name ) : wmsURLFormat;
         layerStruct.wfsURL = wfsURLFormat.contains( "%1" ) ? wfsURLFormat.arg( layerStruct.name ) : wfsURLFormat;
+        layerStruct.wcsURL = wcsURLFormat.contains( "%1" ) ? wcsURLFormat.arg( layerStruct.name ) : wcsURLFormat;
         layerStruct.xyzURL = xyzURLFormat.contains( "%1" ) ? xyzURLFormat.arg( layerStruct.name ) : xyzURLFormat;
       }
     }
@@ -356,17 +364,21 @@ QgsGeoNodeRequest::ServiceLayerDetail QgsGeoNodeRequest::parseOwsUrl( QgsGeoNode
     const QVariantMap linkMap = link.toMap();
     if ( linkMap.contains( QStringLiteral( "link_type" ) ) )
     {
-      if ( linkMap.value( QStringLiteral( "link_type" ) ) == QStringLiteral( "OGC:WMS" ) )
+      if ( linkMap.value( QStringLiteral( "link_type" ) ) == QLatin1String( "OGC:WMS" ) )
       {
         urlFound = layerStruct.wmsURL = linkMap.value( QStringLiteral( "url" ) ).toString();
       }
-      else if ( linkMap.value( QStringLiteral( "link_type" ) ) == QStringLiteral( "OGC:WFS" ) )
+      else if ( linkMap.value( QStringLiteral( "link_type" ) ) == QLatin1String( "OGC:WFS" ) )
       {
         urlFound = layerStruct.wfsURL = linkMap.value( QStringLiteral( "url" ) ).toString();
       }
-      else if ( linkMap.value( QStringLiteral( "link_type" ) ) == QStringLiteral( "image" ) )
+      else if ( linkMap.value( QStringLiteral( "link_type" ) ) == QLatin1String( "OGC:WCS" ) )
       {
-        if ( linkMap.contains( QStringLiteral( "name" ) ) && linkMap.value( QStringLiteral( "name" ) ) == QStringLiteral( "Tiles" ) )
+        urlFound = layerStruct.wcsURL = linkMap.value( QStringLiteral( "url" ) ).toString();
+      }
+      else if ( linkMap.value( QStringLiteral( "link_type" ) ) == QLatin1String( "image" ) )
+      {
+        if ( linkMap.contains( QStringLiteral( "name" ) ) && linkMap.value( QStringLiteral( "name" ) ) == QLatin1String( "Tiles" ) )
         {
           urlFound = layerStruct.xyzURL = linkMap.value( QStringLiteral( "url" ) ).toString();
         }
@@ -445,6 +457,10 @@ QStringList QgsGeoNodeRequest::fetchServiceUrlsBlocking( const QString &serviceT
     {
       url = layer.wfsURL;
     }
+    else if ( QString::compare( serviceType, QStringLiteral( "wcs" ), Qt::CaseInsensitive ) == 0 )
+    {
+      url = layer.wcsURL;
+    }
     else if ( QString::compare( serviceType, QStringLiteral( "xyz" ), Qt::CaseInsensitive ) == 0 )
     {
       url = layer.xyzURL;
@@ -489,6 +505,10 @@ QgsStringMap QgsGeoNodeRequest::fetchServiceUrlDataBlocking( const QString &serv
     {
       url = layer.wfsURL;
     }
+    else if ( QString::compare( serviceType, QStringLiteral( "wcs" ), Qt::CaseInsensitive ) == 0 )
+    {
+      url = layer.wcsURL;
+    }
     else if ( QString::compare( serviceType, QStringLiteral( "xyz" ), Qt::CaseInsensitive ) == 0 )
     {
       url = layer.xyzURL;
@@ -517,7 +537,7 @@ void QgsGeoNodeRequest::request( const QString &endPoint )
   mIsAborted = false;
   // Handle case where the endpoint is full url
   QString url = endPoint.startsWith( mBaseUrl ) ? endPoint : mBaseUrl + endPoint;
-  QgsDebugMsg( "Requesting to " + url );
+  QgsDebugMsgLevel( "Requesting to " + url, 2 );
   setProtocol( url.split( QStringLiteral( "://" ) ).at( 0 ) );
   QUrl layerUrl( url );
   layerUrl.setScheme( protocol() );
@@ -531,10 +551,10 @@ void QgsGeoNodeRequest::request( const QString &endPoint )
 
 bool QgsGeoNodeRequest::requestBlocking( const QString &endPoint )
 {
-  request( endPoint );
-
   QEventLoop loop;
   connect( this, &QgsGeoNodeRequest::requestFinished, &loop, &QEventLoop::quit );
+
+  request( endPoint );
   loop.exec( QEventLoop::ExcludeUserInputEvents );
 
   return mError.isEmpty();
@@ -543,7 +563,7 @@ bool QgsGeoNodeRequest::requestBlocking( const QString &endPoint )
 QNetworkReply *QgsGeoNodeRequest::requestUrl( const QString &url )
 {
   QNetworkRequest request( url );
-  request.setAttribute( QNetworkRequest::FollowRedirectsAttribute, true );
+  request.setAttribute( QNetworkRequest::RedirectPolicyAttribute, 1 );
 
   QgsSetRequestInitiatorClass( request, QStringLiteral( "QgsGeoNodeRequest" ) );
   // Add authentication check here
